#' Create a "fairified" project
#'
#' Create a package ready for fairify your project.
#'
#' @inheritParams usethis::create_package
#' @param tidy if `TRUE`, run [usethis::use_testthat()], [usethis::use_tidy_description()], and [usethis::use_tidy_dependencies()]
#' @param with_reports If `TRUE`, run `create_reports`, preparing package structure for report publications
#' @param git if `TRUE`, initialises a Git repository
#' @param ... Further parameters passed to [usethis::create_package]
#'
#' @return Use for side effect.
#' @export
#'
#' @examples
#' path <- tempfile(pattern = "dir")
#' create_fairify(path, open = FALSE)
#' list.files(path)
create_fairify <-
  function(path,
           tidy = TRUE,
           check_name = FALSE,
           open = rlang::is_interactive(),
           with_reports = TRUE,
           git = TRUE,
           ...) {
    usethis::create_package(path, rstudio = TRUE, open = FALSE, check_name = check_name, ...)
    usethis::proj_set(path)
    if (tidy) {
      usethis::local_project(path)
      usethis::use_testthat()
      usethis::use_tidy_description()
    }
    if (git) {
      gert::git_init(path)
      add_gitignore(path)
    }
    if (with_reports)
      create_reports(path = path)
    usethis::use_package("fairify", "Depends")
    #file.copy()
    if (open) {
      usethis::proj_activate(path)
    }
  }
